aboutsummaryrefslogtreecommitdiffstats
path: root/capture_sync.c
diff options
context:
space:
mode:
Diffstat (limited to 'capture_sync.c')
-rw-r--r--capture_sync.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/capture_sync.c b/capture_sync.c
index 28f2b386c8..2d072fe88c 100644
--- a/capture_sync.c
+++ b/capture_sync.c
@@ -1425,11 +1425,11 @@ sync_pipe_stop(capture_options *capture_opts)
if (capture_opts->fork_child != -1) {
#ifndef _WIN32
- /* send the SIGUSR1 signal to close the capture child gracefully. */
- int sts = kill(capture_opts->fork_child, SIGUSR1);
+ /* send the SIGINT signal to close the capture child gracefully. */
+ int sts = kill(capture_opts->fork_child, SIGINT);
if (sts != 0) {
g_log(LOG_DOMAIN_CAPTURE_CHILD, G_LOG_LEVEL_WARNING,
- "Sending SIGUSR1 to child failed: %s\n", strerror(errno));
+ "Sending SIGINT to child failed: %s\n", strerror(errno));
}
#else
#define STOP_SLEEP_TIME 500 /* ms */